
# Type: in taxon


connects a thing to a class representing a taxon

URI: [biolink:in_taxon](https://w3id.org/biolink/vocab/in_taxon)


## Domain and Range

[ThingWithTaxon](ThingWithTaxon.md) ->  <sub>0..*</sub> [OrganismTaxon](OrganismTaxon.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [RNAProduct](RNAProduct.md)
 * [RNAProductIsoform](RNAProductIsoform.md)
 * [AnatomicalEntity](AnatomicalEntity.md)
 * [Carbohydrate](Carbohydrate.md)
 * [Case](Case.md)
 * [Cell](Cell.md)
 * [CellularComponent](CellularComponent.md)
 * [ChemicalSubstance](ChemicalSubstance.md)
 * [CodingSequence](CodingSequence.md)
 * [Disease](Disease.md)
 * [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)
 * [Drug](Drug.md)
 * [Exon](Exon.md)
 * [Gene](Gene.md)
 * [GeneFamily](GeneFamily.md)
 * [GeneOrGeneProduct](GeneOrGeneProduct.md)
 * [GeneProduct](GeneProduct.md)
 * [GeneProductIsoform](GeneProductIsoform.md)
 * [Genome](Genome.md)
 * [GenomicEntity](GenomicEntity.md)
 * [Genotype](Genotype.md)
 * [GrossAnatomicalStructure](GrossAnatomicalStructure.md)
 * [Haplotype](Haplotype.md)
 * [IndividualOrganism](IndividualOrganism.md)
 * [LifeStage](LifeStage.md)
 * [MacromolecularComplex](MacromolecularComplex.md)
 * [MacromolecularMachine](MacromolecularMachine.md)
 * [Metabolite](Metabolite.md)
 * [MicroRNA](MicroRNA.md)
 * [MolecularEntity](MolecularEntity.md)
 * [NoncodingRNAProduct](NoncodingRNAProduct.md)
 * [PhenotypicFeature](PhenotypicFeature.md)
 * [PopulationOfIndividualOrganisms](PopulationOfIndividualOrganisms.md)
 * [Protein](Protein.md)
 * [ProteinIsoform](ProteinIsoform.md)
 * [SequenceVariant](SequenceVariant.md)
 * [ThingWithTaxon](ThingWithTaxon.md)
 * [Transcript](Transcript.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002162 |
|  | | WD:P703 |
| **In Subsets:** | | translator_minimal |

